@@ -10,7 +10,7 @@ use Alien::Build::Util qw( _mirror _destdir_prefix );
 use JSON::PP ();
 
 # ABSTRACT: Core gather plugin
-our $VERSION = '1.76'; # VERSION
+our $VERSION = '1.91'; # VERSION
 
 
 sub init
@@ -24,7 +24,7 @@ sub init
   $meta->around_hook(
     gather_share => sub {
       my($orig, $build) = @_;
-      
+
       local $ENV{PATH} = $ENV{PATH};
       local $ENV{PKG_CONFIG_PATH} = $ENV{PKG_CONFIG_PATH};
       unshift @PATH, Path::Tiny->new('bin')->absolute->stringify
@@ -34,8 +34,8 @@ sub init
           unshift @PKG_CONFIG_PATH, Path::Tiny->new("$dir/pkgconfig")->absolute->stringify
             if -d "$dir/pkgconfig";
       }
-      
-      $orig->($build) 
+
+      $orig->($build)
     }
   );
 
@@ -44,7 +44,7 @@ sub init
     $meta->around_hook(
       "gather_$type" => sub {
         my($orig, $build) = @_;
-        
+
         if($build->meta_prop->{destdir})
         {
           my $destdir = $ENV{DESTDIR};
@@ -52,14 +52,14 @@ sub init
           {
             my $src = Path::Tiny->new(_destdir_prefix($ENV{DESTDIR}, $build->install_prop->{prefix}));
             my $dst = Path::Tiny->new($build->install_prop->{stage});
-        
+
             my $res = do {
               local $CWD = "$src";
               $orig->($build);
             };
-        
+
             $build->log("mirror $src => $dst");
-        
+
             $dst->mkpath;
             # Please note: _mirror and Alien::Build::Util are ONLY
             # allowed to be used by core plugins.  If you are writing
@@ -69,7 +69,7 @@ sub init
               verbose => 1,
               filter => $build->meta_prop->{$type eq 'share' ? 'destdir_filter' : 'destdir_ffi_filter'},
             });
-        
+
             return $res;
           }
           else
@@ -86,37 +86,37 @@ sub init
           # prefix with the runtime prefix.
           my $old = $build->install_prop->{prefix};
           my $new = $build->runtime_prop->{prefix};
-        
+
           foreach my $flag (qw( cflags cflags_static libs libs_static ))
           {
             next unless defined $build->runtime_prop->{$flag};
             $build->runtime_prop->{$flag} =~ s{(-I|-L|-LIBPATH:)\Q$old\E}{$1 . $new}eg;
           }
-        
+
           return $ret;
         }
       }
     );
   }
-  
+
   $meta->after_hook(
     $_ => sub {
       my($build) = @_;
 
       die "stage is not defined.  be sure to call set_stage on your Alien::Build instance"
         unless $build->install_prop->{stage};
-      
+
       my $stage = Path::Tiny->new($build->install_prop->{stage});
       $build->log("mkdir -p $stage/_alien");
       $stage->child('_alien')->mkpath;
-      
+
       # drop a alien.json file for the runtime properties
       $stage->child('_alien/alien.json')->spew(
-        JSON::PP->new->pretty->encode($build->runtime_prop)
+        JSON::PP->new->pretty->canonical(1)->ascii->encode($build->runtime_prop)
       );
-      
+
       # copy the alienfile, if we managed to keep it around.
-      if($build->meta->filename                 && 
+      if($build->meta->filename                 &&
          -r $build->meta->filename              &&
          $build->meta->filename !~ /\.(pm|pl)$/ &&
          ! -d $build->meta->filename)
@@ -124,7 +124,7 @@ sub init
         Path::Tiny->new($build->meta->filename)
                   ->copy($stage->child('_alien/alienfile'));
       }
-      
+
       if($build->install_prop->{patch} && -d $build->install_prop->{patch})
       {
         # Please note: _mirror and Alien::Build::Util are ONLY
@@ -134,7 +134,7 @@ sub init
         _mirror($build->install_prop->{patch},
                 $stage->child('_alien/patch')->stringify);
       }
-    
+
     },
   ) for qw( gather_share gather_system );
 }
@@ -153,7 +153,7 @@ Alien::Build::Plugin::Core::Gather - Core gather plugin
 
 =head1 VERSION
 
-version 1.76
+version 1.91
 
 =head1 SYNOPSIS
 
